NeuroKit.py 
###############
A Python Toolbox for Statistics and Neurophysiological Signal Processing (EEG, EDA, ECG, EMG...).


Click `here for the main webpage <https://github.com/neuropsychology/NeuroKit.py>`_.

